CallEvent class

Constructors

CallEvent({required String id, required bool isGroup, required bool isVideo, required int offerTime, required String sender, required String peerJid})
CallEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
final
isGroup → bool
final
isVideo → bool
final
offerTime → int
final
peerJid → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → String
final

Methods

copyWith({String? id, bool? isGroup, bool? isVideo, int? offerTime, String? sender, String? peerJid}) → CallEvent
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parse(dynamic data) → List<CallEvent>