MessageAck class

WhatsApp's delivery state of a message (msg.ack).

Constructors

MessageAck()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

device → const int
Reached the recipient's device.
error → const int
pending → const int
played → const int
read → const int
server → const int
Accepted by WhatsApp's server -- the message is sent.