MessageId class

Constructors

MessageId({required bool fromMe, required String remote, required String id, required String serialized})
MessageId.fromJson(Map<String, dynamic> json)
factory

Properties

fromMe → bool
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
remote → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialized → String
final

Methods

copyWith({bool? fromMe, String? remote, String? id, String? serialized}) → MessageId
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited