WhatsappBotUtils class

Constructors

WhatsappBotUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

convertStringToQrCode(String text) → String
convertStringToQrCode will convert a Text into a qrCode , which we can print in Terminal used in scanning code from terminal if we are using this in pure Dart project
enableLogs(bool enable) → void
To print logs from this library set enableLogs(true), by default its false