WhatsappClient class

get WhatsappClient from WhatsappBotFlutter.connect() please do not try to create on your own

Constructors

WhatsappClient({required WpClientInterface wpClient, WppEvents? wppEvents})

Properties

chat ↔ WppChat
latefinal
conn ↔ WppConn
latefinal
connectionEventStream → Stream<ConnectionEvent>
connectionEventStream will give update of Connection Events
no setter
contact ↔ WppContact
latefinal
group ↔ WppGroup
latefinal
hashCode → int
The hash code for this object.
no setterinherited
isAuthenticated → Future<bool>
isAuthenticated is to check if we are loggedIn
no setter
isConnected → bool
isConnected is to check if we are still connected to the WhatsappPage
no setter
isReadyToChat → Future<bool>
isReadyToChat is to check if whatsapp chat Page opened
no setter
labels ↔ WppLabels
latefinal
profile ↔ WppProfile
latefinal
qrCodeStream → Stream<QrCodeImage>
qrCodeStream will give update of QrCode
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ WppStatus
latefinal
wpClient → WpClientInterface
final

Methods

clearSession({bool tryLogout = true}) → Future<void>
clearSession will logout, disconnect and delete the session data
disconnect({bool tryLogout = false}) → Future<void>
disconnect will close the browser instance and set values to null
executeFunction(String function, {bool tryPromise = true}) → Future
To run a custom function on WPP
logout() → Future<void>
logout will try to logout only if We are connected and already logged in
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
off(String event) → Future<void>
To remove listener from any event from WPP
on(String event, dynamic callback(dynamic)) → Future<void>
To list to any event from WPP Get event name from WhatsappEvent
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited