isConnected property
bool
get
isConnected
isConnected is to check if we are still connected to the WhatsappPage
Implementation
bool get isConnected => wpClient.isConnected();
isConnected is to check if we are still connected to the WhatsappPage
bool get isConnected => wpClient.isConnected();