WppAuth class

Constructors

WppAuth(WpClientInterface wpClient)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wpClient ↔ WpClientInterface
getter/setter pair

Methods

isAuthenticated() → Future<bool>
check if User is Authenticated on current opened Page
isMainLoaded() → Future<bool>
check if main is loaded
isMainReady() → Future<bool>
to check if ChatScreen is loaded on the page
isSynced() → Future<bool>
check if data is synced
logout() → Future
To Logout
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited