isValidContact method
check if the given Phone number is a valid phone number Returns false when the number has no WhatsApp account.
Implementation
Future<bool> isValidContact({required String phone}) async {
final result = await wpClient.evaluateJs(
'''(window.WPP.contact.queryWidExists || window.WPP.contact.queryExists)(${phone.phoneParse}).then(function(r) { return !!r; })''',
methodName: "isValidContact",
);
return result == true;
}