WppConn class

Constructors

WppConn(WpClientInterface wpClient)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wpClient ↔ WpClientInterface
getter/setter pair

Methods

getAuthCode() → Future
To get auth Code
getMyDeviceId() → Future
Return the current logged user ID with device id
getMyUserId() → Future
Return the current logged user ID without device id
isIdle() → Future
Check if idle
isMainInit() → Future
Check if main is initialized
isMultiDevice() → Future
Check if multiDevice
isOnline() → Future
Check is online
isRegistered() → Future
Check is the current browser is logged before loading
markAvailable() → Future
Set the online state to online
needsUpdate() → Future
Check if whatsapp web is asking for update
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAlive([bool value = true]) → Future
Set keep alive state, that will force the focused and online state
setMultiDevice(bool value) → Future
If it's true, WhatsApp WEB will switch to MD. If it's false, WhatsApp WEB will switch to Legacy.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited