WppContact class

Constructors

WppContact(WpClientInterface wpClient)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wpClient ↔ WpClientInterface
getter/setter pair

Methods

getContacts() → Future
Return to list of contacts
getProfilePictureUrl({required String phone}) → Future
get ProfilePictureUrl of any Number
getStatus({required String phone}) → Future
Get the current text status of contact
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited