WppEvents class

Constructors

WppEvents(WpClientInterface wpClient)

Properties

connectionEventStreamController → StreamController<ConnectionEvent>
final
hashCode → int
The hash code for this object.
no setterinherited
qrCodeStreamController → StreamController<QrCodeImage>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wpClient ↔ WpClientInterface
getter/setter pair

Methods

init() → Future<void>
call init() once on a page to add eventListeners
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited