WppProfile class

Constructors

WppProfile(WpClientInterface wpClient)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wpClient ↔ WpClientInterface
getter/setter pair

Methods

getMyStatus() → Future
Get your current text status
isBusiness() → Future<bool>
Return the current logged user is Business or not
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setMyProfilePicture({required List<int> imageBytes}) → Future
Update your profile picture
setMyStatus({required String status}) → Future
Update your current text status
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited