WppStatus class

Constructors

WppStatus(WpClientInterface wpClient)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wpClient WpClientInterface
getter/setter pair

Methods

getAllStatus() Future
List all status updates from contacts
getMyStatus() Future
Get status of your own account
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendImageStatus({required List<int> fileBytes, String? caption}) Future
Send an image status
sendTextStatus({required String status, String? backgroundColor, String? font}) Future
Send a text status to your status
sendVideoStatus({required List<int> fileBytes, String? caption}) Future
Send a video status
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited