WhatsappInAppFlutterClient class

Implemented types

Constructors

WhatsappInAppFlutterClient({required InAppWebViewController? controller, String? sessionPath})

Properties

controller ↔ InAppWebViewController?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionPath String?
getter/setter pairoverride

Methods

dispose() Future<void>
override
evaluateJs(String source, {String? methodName, bool tryPromise = true, bool forceJsonParseResult = false}) Future
override
getQrCode() Future<QrCodeImage?>
override
initializeEventListener(OnNewEventFromListener onNewEventFromListener) Future
override
injectJs(String content) Future
override
isConnected() bool
override
loadUrl(String url) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
off(String event) Future<void>
override
on(String event, dynamic callback(dynamic)) Future<void>
override
reload() Future<void>
override
takeScreenshot() Future<Uint8List?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited