WpClientInterface class abstract

Implementers

Constructors

WpClientInterface()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionPath String?
getter/setter pair

Methods

dispose() Future<void>
evaluateJs(String source, {String? methodName, bool tryPromise, bool forceJsonParseResult}) Future
getQrCode() Future<QrCodeImage?>
initializeEventListener(OnNewEventFromListener onNewEventFromListener) Future
injectJs(String content) Future
isConnected() bool
loadUrl(String url) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
off(String event) Future<void>
on(String event, dynamic callback(dynamic)) Future<void>
reload() Future<void>
takeScreenshot() Future<Uint8List?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited