WppGroup class
Constructors
- WppGroup(WpClientInterface wpClient)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wpClient ↔ WpClientInterface
-
getter/setter pair
Methods
-
addParticipants(
{required String groupId, required List< String> phoneNumbers}) → Future - To add participants to a group
-
createGroup(
{required String groupName}) → Future - To add participants to a group
-
demoteParticipants(
{required String groupId, required List< String> phoneNumbers}) → Future - Remove admins from a group
-
getAllGroups(
) → Future -
To get all groups, as plain maps (see
WppChat.getChats). list is the typed version with admin/announce details. -
getParticipants(
{required String groupId}) → Future - To get participants of a group
-
leave(
{required String groupId}) → Future - Leave a group
-
list(
) → Future< List< WhatsappChatSummary> > -
Groups this account is in, light enough for a picker. Pass an item's
idas thephoneof any chat send method. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
promoteParticipants(
{required String groupId, required List< String> phoneNumbers}) → Future - Assign admins to a group
-
removeParticipants(
{required String groupId, required List< String> phoneNumbers}) → Future - To reomve participants from a group
-
setSubject(
{required String groupId, required String subject}) → Future - Set the group subject
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited