WppLabels class

Constructors

WppLabels(WpClientInterface wpClient)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wpClient WpClientInterface
getter/setter pair

Methods

addNewLabel({required String labelName, String? labelColor}) Future
Create a new label
addOrRemoveLabels({required List<String> labelIds, required List<String> chatIds}) Future
Add labels to specific chats
deleteLabel({required String labelId}) Future
Delete a label
getAllLabels() Future
Get all available labels
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited