WppNewsletter class

WhatsApp Channels (wa-js calls them newsletters).

To post to a channel, pass its WhatsappChatSummary.id (...@newsletter) as the phone of chat.sendTextMessage / chat.sendFileMessage. Only the channel's owner and admins can post.

Constructors

WppNewsletter(WpClientInterface wpClient)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wpClient ↔ WpClientInterface
getter/setter pair

Methods

list() → Future<List<WhatsappChatSummary>>
Channels this account owns, administers or follows.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited